-- Using this script: Do a find and replace on the following tables to update them to the current year. (It's alright to let find and replace update this comment too.)
-- Emp_2015
--
-- Script outputs to the following tables: Emp_2015.
-- This script assumes the Emp_2015_Q1, Emp_2015_Q2, Emp_2015_Q3, and Emp_2015_Q4 tables already exist and have data imported into them. This script should create the Emp_2015 table, which combines these 4 tables together.
-- Small adjustments may need to be made to correct discrepencies between years.
-- Expected run time: 5-15 minutes, depending on how long data normalization takes.

use [MSU]

IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Emp_2015')
BEGIN
	DROP TABLE Emp_2015;
END

--Data normalization
UPDATE Emp_2015_q1 
SET UI_ACCT = RIGHT('0000000000' + UI_ACCT, 10), RPT_UNIT = RIGHT('00000' + RPT_UNIT, 5);

UPDATE Emp_2015_q2 
SET UI_ACCT = RIGHT('0000000000' + UI_ACCT, 10), RPT_UNIT = RIGHT('00000' + RPT_UNIT, 5);

UPDATE Emp_2015_q3 
SET UI_ACCT = RIGHT('0000000000' + UI_ACCT, 10), RPT_UNIT = RIGHT('00000' + RPT_UNIT, 5);

UPDATE Emp_2015_q4 
SET UI_ACCT = RIGHT('0000000000' + UI_ACCT, 10), RPT_UNIT = RIGHT('00000' + RPT_UNIT, 5);

select *
into Emp_2015
from Emp_2015_Q1;

exec sp_rename 'Emp_2015.REACT_MOM', 'REACT_MON', 'COLUMN';

alter table Emp_2015 add QCEW_Seq bigint IDENTITY(1, 1) PRIMARY KEY;
alter table Emp_2015 add M4_EMPL nvarchar(8) null;
alter table Emp_2015 add M5_EMPL nvarchar(8) null;
alter table Emp_2015 add M6_EMPL nvarchar(8) null;
alter table Emp_2015 add M7_EMPL nvarchar(8) null;
alter table Emp_2015 add M8_EMPL nvarchar(8) null;
alter table Emp_2015 add M9_EMPL nvarchar(8) null;
alter table Emp_2015 add M10_EMPL nvarchar(8) null;
alter table Emp_2015 add M11_EMPL nvarchar(8) null;
alter table Emp_2015 add M12_EMPL nvarchar(8) null;

BEGIN TRAN
	MERGE Emp_2015 AS qcew
	USING Emp_2015_q2 AS q2
	ON (q2.rpt_unit = qcew.rpt_unit AND q2.ui_acct = qcew.ui_acct)
	WHEN NOT MATCHED BY TARGET
		THEN INSERT(YEAR, QTR, UI_ACCT, RPT_UNIT, EIN, LEGAL_NAME, TRADE_NAME, UI_ADDRESS, UI_ADDRESS_2, UI_CITY, UI_STATE, UI_ZIP_5, MLOT_ADDRESS, MLOT_ADDRESS2, MLOT_CITY, MLOT_STATE, MLOT_ZIP_5, ADDR_TYPE, CNTY, OWN_1, NAICS, TOTAL_WAGE, [Number  of Years in Business], SETUP_MON, SETUP_DAY, SETUP_YEAR, LIAB_MON, LIAB_DAY, LIAB_YEAR, EOL_MON, EOL_DAY, EOL_YEAR, REACT_MON, REACT_DAY, REACT_YEAR, RPT_UNIT_DESC, MEEI, M4_EMPL, M5_EMPL, M6_EMPL)
		VALUES(q2.YEAR, q2.qtr, q2.ui_acct, q2.rpt_unit, q2.ein, q2.legal_name, q2.trade_name, q2.ui_address, q2.ui_address_2, q2.ui_city, q2.ui_state, q2.ui_zip_5, q2.mlot_address, q2.mlot_address2, q2.mlot_city, q2.mlot_state, q2.mlot_zip_5, q2.addr_type, q2.cnty, q2.own_1, q2.naics, q2.total_wage, q2.[Number  of Years in Business], q2.setup_mon, q2.setup_day, q2.setup_year, q2.liab_mon, q2.liab_day, q2.liab_year, q2.eol_mon, q2.eol_day, q2.eol_year, q2.react_mon, q2.react_day, q2.react_year, q2.rpt_unit_desc, q2.meei, q2.m1_empl, q2.m2_empl, q2.m3_empl)
	WHEN MATCHED
		THEN UPDATE SET qcew.M4_EMPL = q2.M1_EMPL, qcew.M5_EMPL = q2.M2_EMPL, qcew.M6_EMPL = q2.M3_EMPL
	OUTPUT $action;
COMMIT TRAN;

BEGIN TRAN
	MERGE Emp_2015 AS qcew
	USING Emp_2015_q3 AS q2
	ON (q2.rpt_unit = qcew.rpt_unit AND q2.ui_acct = qcew.ui_acct)
	WHEN NOT MATCHED BY TARGET
		THEN INSERT(YEAR, QTR, UI_ACCT, RPT_UNIT, EIN, LEGAL_NAME, TRADE_NAME, UI_ADDRESS, UI_ADDRESS_2, UI_CITY, UI_STATE, UI_ZIP_5, MLOT_ADDRESS, MLOT_ADDRESS2, MLOT_CITY, MLOT_STATE, MLOT_ZIP_5, ADDR_TYPE, CNTY, OWN_1, NAICS, TOTAL_WAGE, [Number  of Years in Business], SETUP_MON, SETUP_DAY, SETUP_YEAR, LIAB_MON, LIAB_DAY, LIAB_YEAR, EOL_MON, EOL_DAY, EOL_YEAR, REACT_MON, REACT_DAY, REACT_YEAR, RPT_UNIT_DESC, MEEI, M7_EMPL, M8_EMPL, M9_EMPL)
		VALUES(q2.YEAR, q2.qtr, q2.ui_acct, q2.rpt_unit, q2.ein, q2.legal_name, q2.trade_name, q2.ui_address, q2.ui_address_2, q2.ui_city, q2.ui_state, q2.ui_zip_5, q2.mlot_address, q2.mlot_address2, q2.mlot_city, q2.mlot_state, q2.mlot_zip_5, q2.addr_type, q2.cnty, q2.own_1, q2.naics, q2.total_wage, q2.[Number  of Years in Business], q2.setup_mon, q2.setup_day, q2.setup_year, q2.liab_mon, q2.liab_day, q2.liab_year, q2.eol_mon, q2.eol_day, q2.eol_year, q2.react_mon, q2.react_day, q2.react_year, q2.rpt_unit_desc, q2.meei, q2.m1_empl, q2.m2_empl, q2.m3_empl)
	WHEN MATCHED
		THEN UPDATE SET qcew.M7_EMPL = q2.M1_EMPL, qcew.M8_EMPL = q2.M2_EMPL, qcew.M9_EMPL = q2.M3_EMPL
	OUTPUT $action;
COMMIT TRAN;

BEGIN TRAN
	MERGE Emp_2015 AS qcew
	USING Emp_2015_q4 AS q2
	ON (q2.rpt_unit = qcew.rpt_unit AND q2.ui_acct = qcew.ui_acct)
	WHEN NOT MATCHED BY TARGET
		THEN INSERT(YEAR, QTR, UI_ACCT, RPT_UNIT, EIN, LEGAL_NAME, TRADE_NAME, UI_ADDRESS, UI_ADDRESS_2, UI_CITY, UI_STATE, UI_ZIP_5, MLOT_ADDRESS, MLOT_ADDRESS2, MLOT_CITY, MLOT_STATE, MLOT_ZIP_5, ADDR_TYPE, CNTY, OWN_1, NAICS, TOTAL_WAGE, [Number  of Years in Business], SETUP_MON, SETUP_DAY, SETUP_YEAR, LIAB_MON, LIAB_DAY, LIAB_YEAR, EOL_MON, EOL_DAY, EOL_YEAR, REACT_MON, REACT_DAY, REACT_YEAR, RPT_UNIT_DESC, MEEI, M10_EMPL, M11_EMPL, M12_EMPL)
		VALUES(q2.YEAR, q2.qtr, q2.ui_acct, q2.rpt_unit, q2.ein, q2.legal_name, q2.trade_name, q2.ui_address, q2.ui_address_2, q2.ui_city, q2.ui_state, q2.ui_zip_5, q2.mlot_address, q2.mlot_address2, q2.mlot_city, q2.mlot_state, q2.mlot_zip_5, q2.addr_type, q2.cnty, q2.own_1, q2.naics, q2.total_wage, q2.[Number  of Years in Business], q2.setup_mon, q2.setup_day, q2.setup_year, q2.liab_mon, q2.liab_day, q2.liab_year, q2.eol_mon, q2.eol_day, q2.eol_year, q2.react_mon, q2.react_day, q2.react_year, q2.rpt_unit_desc, q2.meei, q2.m1_empl, q2.m2_empl, q2.m3_empl)
	WHEN MATCHED
		THEN UPDATE SET qcew.M10_EMPL = q2.M1_EMPL, qcew.M11_EMPL = q2.M2_EMPL, qcew.M12_EMPL = q2.M3_EMPL
	OUTPUT $action;
COMMIT TRAN;